DSCR_DEVICE   	 equ   1   			;; Descriptor type: Device
DSCR_CONFIG  	 equ   2   			;; Descriptor type: Configuration
DSCR_STRING   	 equ   3  		 	;; Descriptor type: String
DSCR_INTRFC   	 equ   4   			;; Descriptor type: Interface
DSCR_ENDPNT   	 equ   5   			;; Descriptor type: Endpoint
DSCR_DEVQUAL  	 equ   6   			;; Descriptor type: Device Qualifier
DSCR_OTHERSPEED  equ   7 


ET_CONTROL   equ   0   				;; Endpoint type: Control
ET_ISO       equ   1   				;; Endpoint type: Isochronous
ET_BULK      equ   2   				;; Endpoint type: Bulk
ET_INT       equ   3   				;; Endpoint type: Interrupt

public	DeviceDscr,ConfigDscr,StringDscr, StringDscr0, StringDscr1, StringDscr2
public  HighSpeedConfigDscr,FullSpeedConfigDscr,DeviceQualDscr, UserDscr
public  CSACIntDscr,STDACIntDscr
 
; Cypress VID is 04B4h.   
VID	equ	04B4h
PID	equ	1234h
DID 	equ	0000h

;cseg at 0x90
DSCR   SEGMENT   CODE PAGE

;;-----------------------------------------------------------------------------
;; Global Variables
;;-----------------------------------------------------------------------------
      rseg DSCR      ;; locate the descriptor table in on-part memory.






DeviceDscr:	
	db	12h		; Descriptor length
	db	DSCR_DEVICE			; Descriptor type = DEVICE
	db	0,02h				; spec version (BCD) is 2.00               
	db	0,0,0				; HID class is defined in the interface descriptor
	db	64				; maxPacketSize
	db	LOW(VID),HIGH(VID)
	db	LOW(PID),HIGH(PID)
	db	LOW(DID),HIGH(DID)
	db  	 1        			; Manufacturer string index
      	db  	 2         			; Product string index
      	db  	 0         			; Serial number string index
      	db  	 1         			; Number of configurations

DeviceQualDscr:
    db  0Ah      ;Descriptor Length
    db  DSCR_DEVQUAL        			;Descriptor Type
    db  0,02h            			;spec version (BCD) is 2.00
    db  0,0,0               			;Device class, sub-class, and sub-sub-class
    db  64                 			;Max Packet Size
    db  1                  		 	;Number of configurations
    db  0                   			;Reserved

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;		DESCRIPTION FOR AUDIO DEVICE IN HIGH SPEED
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

HighSpeedConfigDscr:
ConfigDscr:
	db	09h			; Descriptor length
    db	DSCR_CONFIG		; Descriptor type = CONFIG
	db	LOW(HS_End-ConfigDscr)	; total length (conf+interface+HID+EP's)
	db	HIGH(HS_End-ConfigDscr)
	db	02h			; number of interfaces
	db	01h			; ID of the configuration
	db	0			; unused
	db	10000000b		; b7=1; b6=self-powered; b5=Remote WU
	db	40d			; bus power = 80 ma

STDACIntDscr:	; Standard Audio Control Interface Descriptor
	db	09h			; Descriptor length
	db	04h			; Descriptor type = INTERFACE
	db	0			; Index of the interface
	db	0			; Index of the setting
	db	0			; 0 endpoint
	db	01h
	db	01h
	db	0		        ; class(01)AUDIO, subclass(01)AUDIO_CONTROL and no protocol
	db	0			; unused

CSACIntDscr:	; Class-Specific Audio Control Interface Descriptor
	db	09h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	01h			; Descriptor SubType - HEADER
	db	0
	db	01h

	db	27h			; Total size of class specific descriptors
	db	0
	db  01h		; Number of streaming interfaces
	db	01h			; AudioStreaming interface 1 belongs to this AudioControl interface

InTermDscr:	; Input Terminal Descriptor
	db	0Ch			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	02h			; Descriptor SubType - INPUT_TERMINAL
	db	01h			; ID of the terminal
	db	01h			; Terminal is Streaming
	db	01h
	db	0			; No association
	db	01h			; 1 channel
	db	0,0			; Mono sets no position bits
	db	0			; Unused
	db	0			; Unused

FeatureDscr:	; Feature Descriptor for Volume control
	db	09h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	06h			; Descriptor SubType - FEATURE_UNIT
	db	03h			; Feature ID
	db	01h			; Source ID - From input terminal
    db  01h                     ; size of bitmap
	db	03h			; bitmap
    db  03h 
	db	00h			; index to string descr
	
	
OutTermDscr:	; Output Terminal Descriptor
	db	09h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	03h			; Descriptor SubType - OUTPUT_TERMINAL
	db	02h			; ID of the terminal
	db	01h,03h		        ; USB speaker
	db	0			; No association
	db	03h			; SourceID - From Feature Unit
	db	0			; unused


STDASIntDscr:	; Standard Audio Streaming Interface Descriptor
	db	09h			; Descriptor length
	db	04h			; Descriptor type - INTERFACE
	db	01h			; Index of the interface
	db	0			; Index of the alternate setting
	db	1			; 1 endpoint
	db	01h			; Class(01)AUDIO
	db	02h			; SubClass(02)AUDIO_STREAMING
	db	0			; unused
	db	0			; unused

STDASInt2Dscr:	; Standard Audio Streaming Interface Descriptor
	db	09h			; Descriptor length
	db	04h			; Descriptor type - INTERFACE
	db	01h			; Index of the interface
	db	01h			; Index of the alternate setting
	db	0			; 0 endpoint
	db	01h			; Class(01)AUDIO
	db	02h			; SubClass(02)AUDIO_STREAMING
	db	0			; unused
	db	0			; unused


CSASIntDscr:	; Class Specific Audio Streaming Interface Descriptor
	db	07h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	01h			; Descriptor SubType - GENERAL
	db	01h			; ID of the input terminal
	db	01h			; Interface delay
	db	01h			; PCM format*/
	db	0

	
FormatTypeDscr:	; Type I Format Type Descriptor
	db	0Bh			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	02h			; Descriptor SubType - FORMAT_TYPE
	db	01h			; FORMAT_TYPE_I
	db	01h			; 1 channel
	db	02h			; 2 bytes per audio subframe
	db	10h			; 16 bits per sample
	db	01h			; 1 frequency supported
	db	40h
	db	1Fh
	db	0

STDEPDscr:	; Standard Endpoint Descriptor
	db	09h			; Descriptor length
	db	05h			; Descriptor type - ENDPOINT
	db	06h			; OUT Endpoint 1
	db	01h			; Isochronous, not shared
	db	10h			; 16 bytes per packet
	db	0
	db	01h			; 1 packet per frame
	db	0			; unused
	db	0			; unused

CSIsoEPDscr:	; Class-Specific Isochronous Audio Data Endpoint Descriptor
	db	07h			; Descriptor length
	db	25h			; Descriptor type - CS_ENDPOINT
	db	01h			; Descriptor SubType - GENERAL
	db	0			; No sampling frequency control, no pitch control, no packet padding
	db	0			; unused
	db	0,0			; unused
	
HS_End:

;    	db  00h         ; Word alignment

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;		DESCRIPTION FOR AUDIO DEVICE IN FULL SPEED
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

FullSpeedConfigDscr:
FSConfigDscr:
	db	09h			; Descriptor length
        db	DSCR_CONFIG		; Descriptor type = CONFIG
	db	LOW(FS_End-FSConfigDscr)	; total length (conf+interface+HID+EP's)
	db	HIGH(FS_End-FSConfigDscr)
	db	02h			; number of interfaces
	db	01h			; ID of the configuration
	db	0			; unused
	db	10000000b		; b7=1; b6=self-powered; b5=Remote WU
	db	40d			; bus power = 80 ma

FSSTDACIntDscr:	; Standard Audio Control Interface Descriptor
	db	09h			; Descriptor length
	db	04h			; Descriptor type = INTERFACE
	db	0			; Index of the interface
	db	0			; Index of the setting
	db	0			; 0 endpoint
	db	01h
	db	01h
	db	0		; class(01)AUDIO, subclass(01)AUDIO_CONTROL and no protocol
	db	0			; unused

FSCSACIntDscr:	; Class-Specific Audio Control Interface Descriptor
	db	09h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	01h			; Descriptor SubType - HEADER
	db	0
	db	01h
	db	1Eh			; Total size of class specific descriptors
	db	0
	db	01h			; Number of streaming interfaces
	db	01h			; AudioStreaming interface 1 belongs to this AudioControl interface

FSInTermDscr:	; Input Terminal Descriptor
	db	0Ch			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	02h			; Descriptor SubType - INPUT_TERMINAL
	db	01h			; ID of the terminal
	db	01h			; Terminal is Streaming
	db	01h
	db	0			; No association
	db	01h			; 1 channel
	db	0,0			; Mono sets no position bits
	db	0			; Unused
	db	0			; Unused

FSFeatureDscr:	; Feature Descriptor
	db	09h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	06h			; Descriptor SubType - FEATURE_UNIT
	db	03h			; Feature ID
	db	01h			; Source ID - From input terminal
	db	01h			; bitmap size
	db	03h			; bitmap
	db	0			; unused
	db	0			; unused

FSOutTermDscr:	; Output Terminal Descriptor
	db	09h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	03h			; Descriptor SubType - OUTPUT_TERMINAL
	db	02h			; ID of the terminal
	db	01h,03h		; USB streaming
	db	0			; No association
	db	03h			; SourceID - From Feature Unit
	db	0			; unused

FSSTDASIntDscr:	; Standard Audio Streaming Interface Descriptor
	db	09h			; Descriptor length
	db	04h			; Descriptor type - INTERFACE
	db	01h			; Index of the interface
	db	0			; Index of the alternate setting
	db	0			; 0 endpoint
	db	01h			; Class(01)AUDIO
	db	02h			; SubClass(02)AUDIO_STREAMING
	db	0			; unused
	db	0			; unused

FSSTDASInt2Dscr:	; Standard Audio Streaming Interface Descriptor
	db	09h			; Descriptor length
	db	04h			; Descriptor type - INTERFACE
	db	01h			; Index of the interface
	db	01h			; Index of the alternate setting
	db	01h			; 1 endpoint
	db	01h			; Class(01)AUDIO
	db	02h			; SubClass(02)AUDIO_STREAMING
	db	0			; unused
	db	0			; unused

FSCSASIntDscr:	; Class Specific Audio Streaming Interface Descriptor
	db	07h			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	01h			; Descriptor SubType - GENERAL
	db	01h			; ID of the input terminal
	db	01h			; Interface delay
	db	01h			; PCM format*/
	db	0

FSFormatTypeDscr:	; Type I Format Type Descriptor
	db	0Bh			; Descriptor length
	db	24h			; Descriptor type - CS_INTERFACE
	db	02h			; Descriptor SubType - FORMAT_TYPE
	db	01h			; FORMAT_TYPE_I
	db	01h			; 1 channel
	db	02h			; 2 bytes per audio subframe
	db	10h			; 16 bits per sample
	db	01h			; 1 frequency supported
	db	40h
	db	1Fh
	db	0

FSSTDEPDscr:	; Standard Endpoint Descriptor
	db	09h			; Descriptor length
	db	05h			; Descriptor type - ENDPOINT
	db	06h			; OUT Endpoint 1
	db	01h			; Isochronous, not shared
	db	10h			; 16 bytes per packet
	db	0
	db	01h			; 1 packet per frame
	db	0			; unused
	db	0			; unused

FSCSIsoEPDscr:	; Class-Specific Isochronous Audio Data Endpoint Descriptor
	db	07h			; Descriptor length
	db	25h			; Descriptor type - CS_ENDPOINT
	db	01h			; Descriptor SubType - GENERAL
	db	0			; No sampling frequency control, no pitch control, no packet padding
	db	0			; unused
	db	0,0			; unused
	
FS_End:

StringDscr:
StringDscr0:
		db	StringDscr0End-StringDscr0		;; String descriptor length
		db	DSCR_STRING
		db	09H,04H
StringDscr0End:

StringDscr1:	
		db	StringDscr1End-StringDscr1		;; String descriptor length
		db	DSCR_STRING
		db	'E',00
		db	'x',00
		db	'a',00
		db	'm',00
		db	'p',00
		db	'l',00
		db	'e',00

StringDscr1End:
StringDscr2:	
		db	StringDscr2End-StringDscr2		;; Descriptor length
		db	DSCR_STRING
		db	'F',00
		db	'X',00
		db	'-',00
		db	'S',00
		db	'p',00
		db	'e',00
		db	'a',00
		db	'k',00
		db	'e',00
		db	'r',00
StringDscr2End:
	

StringDscr3:	
		db	StringDscr3End-StringDscr3		;; Descriptor length
		db	DSCR_STRING
		db	'F',00
		db	'X',00
		db	'-',00
		db	'S',00
		db	'p',00
		db	'e',00
		db	'a',00
		db	'k',00
		db	'e',00
		db	'r',00
StringDscr3End:


UserDscr:		
		dw	0000H
		end



