;;-----------------------------------------------------------------------------
;;   File:      dscr.a51
;;   Contents:   This file contains descriptor data tables.  
;;
;;   Copyright (c) 2003 Cypress Semiconductor, Inc. All rights reserved
;;-----------------------------------------------------------------------------
;; this for USB audio spec 2.0
   
DSCR_DEVICE   equ   1   ;; Descriptor type: Device
DSCR_CONFIG   equ   2   ;; Descriptor type: Configuration
DSCR_STRING   equ   3   ;; Descriptor type: String
DSCR_INTRFC   equ   4   ;; Descriptor type: Interface
DSCR_AS_INTRFC   equ   0x24   ;; Descriptor type: AS Interface
DSCR_ENDPNT   equ   5   ;; Descriptor type: Endpoint
DSCR_DEVQUAL  equ   6   ;; Descriptor type: Device Qualifier
DSCR_OTH_SPD  equ   7   ;; Descriptor type: Other Speed Configuration
DSCR_IF_POW   equ   8   ;; Descriptor type: Interface Power
DSCR_OTG      equ   9   ;; Descriptor type: OTG
DSCR_DEBUG    equ   10  ;; Descriptor type: DEBUG
DSCR_IF_ASSOC equ   11  ;; Descriptor type: Interface Association

DSCR_DEVICE_LEN   equ   18
DSCR_CONFIG_LEN   equ    9
DSCR_INTRFC_LEN   equ    9
DSCR_AS_INTRFC_LEN   equ    16
DSCR_ENDPNT_LEN   equ    7
DSCR_DEVQUAL_LEN  equ   10
DSCR_OTH_SPD_LEN  equ   0FFH	;; needs correction
DSCR_IF_POW_LEN   equ   0FFH	;; needs correction
DSCR_OTG_LEN      equ   0FFH	;; needs correction
DSCR_DEBUG_LEN    equ   0FFH	;; needs correction
DSCR_IF_ASSOC_LEN equ   8

ET_CONTROL   equ   0   ;; Endpoint type: Control
ET_ISO       equ   1   ;; Endpoint type: Isochronous
ET_BULK      equ   2   ;; Endpoint type: Bulk
ET_INT       equ   3   ;; Endpoint type: Interrupt

public      DeviceDscr, DeviceQualDscr, HighSpeedConfigDscr, FullSpeedConfigDscr, StringDscr, UserDscr

public      HIDDscr, HIDReportDscr, HIDReportDscrEnd

;DSCR   SEGMENT   CODE

;;-----------------------------------------------------------------------------
;; Global Variables
;;-----------------------------------------------------------------------------
;      rseg DSCR     ;; locate the descriptor table in on-part memory.

CSEG   AT 100H


DeviceDscr:   
	db   DSCR_DEVICE_LEN      ;; Descriptor length
	db   DSCR_DEVICE   ;; Decriptor type
	db   00H      ;; Specification Version (BCD) LS
	db   02H      ;; Specification Version (BCD) MS
	db   0EFH        ;; bDeviceClass
	db   02H         ;; bDeviceSubClass
	db   01H         ;; bDeviceProtocol
	db   64         ;; Maximum packet size
	db   004H      ;; idVendor	(LS)
	db   0B4H      ;; idVendor  (MS)
	db   0feH      ;; idProduct (MGN Device) LS
	db   003H      ;; idProduct (MGN Device) MS
	db   001H      ;; bcdDevice (Product version ID)	LS
	db   0A0H      ;; bcdDevice (Product version ID) MS
	db   0         ;; iManufacturer Manufacturer string index
	db   0         ;; iProduct Product string index
	db   0         ;; iSerialNumber Serial number string index
	db   1         ;; Number of configurations

org (($+1)/2)*2	;; align to even address

DeviceQualDscr:
	db   DSCR_DEVQUAL_LEN		;; bLength
	db   DSCR_DEVQUAL			;; bDescriptor
	db   00H      				;; Specification Version (BCD) LS
	db   02H  				    ;; Specification Version (BCD) MS
	db   0EFH					;; bDeviceClass
	db   02H					;; bDeviceSubClass
	db   01H					;; bDeviceProtocol
	db   64						;; bMaxPacketSize0
	db   1						;; bNumConfigurations
	db   0						;; bReserved

org (($+1)/2)*2	;; align to even address

HighSpeedConfigDscr:   
	db   DSCR_CONFIG_LEN		;; bLength
	db   DSCR_CONFIG			;; bDescriptorType
	db   (HighSpeedConfigDscrEnd-HighSpeedConfigDscr) mod 256 ;; wTotalLength	(LSB)
	db   (HighSpeedConfigDscrEnd-HighSpeedConfigDscr)  /  256 ;; wTotalLength (MSB)
	db   1						;; bNumInterfaces
	db   1						;; bConfigurationValue (Configuration number)
	db   0						;; iConfiguration (Configuration string)
	db   10100000b				;; bmAttributes Attributes (b7 - buspwr, b6 - selfpwr, b5 - rwu)
	db   50						;; Power requirement (div 2 ma)

;; Interface Assocation Descriptor
	db   DSCR_IF_ASSOC_LEN 		;; bLength
	db   DSCR_IF_ASSOC     		;; bDescriptorType
	db   0                 		;; bFirstInterface Zero-based index of this interface
	db   2                 		;; bInterfaceCount ( Control, and AudioStreaming)
	db   1                 		;; bFunctionClass AUDIO_FUNCTION
	db   0	             		;; bFunctionSubClass FUNCTION_SUBCLASS_UNDEFINED
	db   020H              		;; bFunctionProtocol AF_VERSION_02_00
	db   0                 		;; iFunction Interface descriptor string index This would be nice to add!
      
;; Alt 0 Interface Descriptor - Control
	db   DSCR_INTRFC_LEN   		;; bLength
	db   DSCR_INTRFC       		;; bDescriptorType	 INTERFACE
	db   0                 		;; bInterfaceNumber Zero-based index of this interface
	db   0                 		;; bAlternateSetting
	db   0                 		;; bNumEndpoints 	 0 = Control Only; 1 = Control + Interrupt
	db   01H               		;; bInterfaceClass AUDIO
	db   01H               		;; bInterfaceSubClass AUDIOCONTROL
	db   020H              		;; bInterfaceProtocol IP_VERSION_02_00
	db   0                 		;; iInterface descriptor string index This would be nice to add!
						  	
;; Class specific Audio Control Descriptor - concat all Clock Descriptor, Ubnit Descriptors, Terminal Desriptors
HighSpeedACDescStrt:	  
;; AC Interface header
	db   09H				 ;; bLength				  9
	db   24H				 ;; bDescriptorType		  CS_INTERFACE
	db   01H				 ;; bDescriptorSubtype	  HEADER
	db   00H				 ;; bcdADC				  VERSION LS
	db   02H				 ;; bcdADC				  VERSION MS
	db   08H				 ;; bCategory			  I/O_BOX
	db   (HighSpeedACDescEnd-HighSpeedACDescStrt) mod 256 ;; wTotalLength	(LSB)
	db   (HighSpeedACDescEnd-HighSpeedACDescStrt)  /  256 ;; wTotalLength (MSB)
	db   00H				 ;; bmControls 00000xx xx indicates Latency Control

;; Clock Source
	db	08H					;;	bLength				8
	db	24H					;;	bDescriptorType		CS_INTERFACE
	db	0AH					;;	bDescriptorSubtype	CLOCK_SOURCE
	db	01H					;;	bClockID			unique
	db	07H					;;	bmAttributes		6 = variable freq synced to SOM 7 = prog but synched to SOF
	db	07H					;;	bmControls			6 = read only control with validity read only; 0 - no controls present
							;;						7 = fully controllable but read only Validity
	db	02H					;;	bAssocTerminal		2 = USB OUT terminal
	db	00H					;;	iClockSource  		descr string

;; Input Terminal
	db	11H					;;	bLength				17
	db	24H					;;	bDescriptorType		CS_INTERFACE
	db	02H					;;	bDescriptorSubtype	INPUT_TERMINAL
	db	02H					;;	bTerminalID			unique
	db	01H					;;	wTerminalType		usb streaming LS
	db	01H					;;	wTerminalType		usb streaming MS
	db	00H					;;	bAssocTerminal
	db	01H					;;	bCSourceID			Clock source ID
	db	02H					;;	bNrChannels			Stereo
	db	03H					;;	bmChannelConfig		Front Left and Front Right	(LS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(most MS)
	db	00H					;;	iChannelNames
	db	00H					;;	bmControls			Not implemented	LS
	db	00H					;;	bmControls			Not implemented MS
	db	00H					;;	iTerminal

;; Output Terminal
	db	0CH					;;	bLength				12
	db	24H					;;	bDescriptorType		CS_INTERFACE
	db	03H					;;	bDescriptorSubtype	OUTPUT_TERMINAL
	db	03H					;;	bTerminalID			unique
	db	01H					;;	wTerminalType		A generic analog connector. LS
	db	06H					;;	wTerminalType		A generic analog connector.	MS
	db	00H					;;	bAssocTerminal		
	db	02H					;;	bCSourceID			Data source ID
	db	01H					;;	bCSourceID			Clock source ID
	db	00H					;;	bmControls			Not implemented	LS
	db	00H					;;	bmControls			Not implemented MS
	db	00H					;;	iTerminal

HighSpeedACDescEnd:
;; Control Endpoint Descriptor NEVER EXPLICITLY DECLARED

;; Interrupt Endpoint Descriptor
;;	db	DSCR_ENDPNT_LEN   ;; Descriptor length
;;	db	DSCR_ENDPNT       ;; Descriptor type
;;	db	81H               ;; Endpoint 1 and direction IN
;;	db	ET_INT            ;; Endpoint type
;;	db	06H               ;; Maximun packet size (LSB)
;;	db	00H               ;; Max packect size (MSB)  6 byte packets/uFrame
;;	db	04H               ;; Polling interval once per 8 uframe ie 1kHz rate

;; Alt 0 Interface Descriptor - AudioStreaming
	db	DSCR_INTRFC_LEN   ;; bLength
	db	DSCR_INTRFC       ;; bDescriptorType
	db	0                 ;; bInterfaceNumber Zero-based index of this interface
	db	0                 ;; bAlternateSetting
	db	0                 ;; bNumEndpoints 0 Default with no bandwidth
	db	01H               ;; bInterfaceClass AUDIO
	db	02H               ;; bInterfaceSubClass AUDIOSTREAMING
	db	020H              ;; bInterfaceProtocol IP_VERSION_02_00
	db	0                 ;; iInterface descriptor string index This would be nice to add!
      
;; Alt 1 Interface Descriptor - AudioStreaming
	db	DSCR_INTRFC_LEN   ;; bLength
	db	DSCR_INTRFC       ;; bDescriptorType
	db	0                 ;; bInterfaceNumber Zero-based index of this interface
	db	1                 ;; bAlternateSetting
	db	1                 ;; bNumEndpoints Main endpoint
	db	01H               ;; bInterfaceClass AUDIO
	db	02H               ;; bInterfaceSubClass AUDIOSTREAMING
	db	020H              ;; bInterfaceProtocol IP_VERSION_02_00
	db	0                 ;; iInterface descriptor string index This would be nice to add!
      
;; Alt 1 Interface Descriptor - Class Specific AudioStreaming
	db	DSCR_AS_INTRFC_LEN	;; bLength
	db	DSCR_AS_INTRFC		;; bDescriptorType	   CS_INTERFACE
	db	01H					;; bDescriptorSubType   AS_GENERAL
	db	2					;; bTerminalLink ID of assoc link (USB streaming)
	db	00H					;; bmControls not implemented
	db	01H					;; bFormatType	FORMAT_TYPE_I
	db	01H					;; bmFormats PCM LS
	db	00H					;; bmFormats PCM
	db	00H					;; bmFormats PCM
	db	00H					;; bmFormats PCM MS
	db	02H					;; bNrChannels			Stereo
	db	03H					;;	bmChannelConfig		Front Left and Front Right	(LS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(most MS)
	db	00H					;; iChannelNames

;; FORMAT_TYPE_I descriptor      
	db	6					;; bLength
	db	DSCR_AS_INTRFC		;; bDescriptorType	   CS_INTERFACE
	db	02H					;; bDescriptorSubType   FORMAT_TYPE
	db	01H					;; bFormatType	FORMAT_TYPE_I
	db	06H					;; bSubslotSize
	db	18H					;; bBitResolution
      
;; Endpoint Descriptor
	db	DSCR_ENDPNT_LEN   ;; Descriptor length
	db	DSCR_ENDPNT       ;; Descriptor type
	db	02H               ;; Endpoint 2 and direction OUT
	db	ET_ISO+0CH        ;; Endpoint type ISO and Synchronous
	db	00H               ;; wMaxPacketSize (LSB)
	db	01H               ;; wMaxPacketSize (MSB)  256 byte packets/uFrame
	db	01H               ;; Polling interval 1 per uFrame

;; AudioStreaming Class Specific Endpoint descriptor
	db	8					;; bLength
	db	0x25				;; bDescriptorType	   CS_ENDPOINT
	db	0x01				;; bDescriptorSubType	   EP_GENERAL
	db	0x00				;; bmAttributes 0x00 = can handle short packets
							;;				0x80 = always needs correct no of packets above
	db	00H					;; bmControls not implemented
	db	01H					;; bLockDelayUnits ms
	db	00H					;; wLockDelay 0.512s LS
	db	02H					;; wLockDelay 0.512s MS

HighSpeedConfigDscrEnd:   

org (($+1)/2)*2	;; align to even address

FullSpeedConfigDscr:   
	db	DSCR_CONFIG_LEN		;; bLength
	db	DSCR_CONFIG			;; bDescriptorType
	db	(FullSpeedConfigDscrEnd-FullSpeedConfigDscr) mod 256 ;; wTotalLength	(LSB)
	db	(FullSpeedConfigDscrEnd-FullSpeedConfigDscr)  /  256 ;; wTotalLength (MSB)
	db	1					;; bNumInterfaces
	db	1					;; bConfigurationValue (Configuration number)
	db	0					;; iConfiguration (Configuration string)
	db	10100000b			;; bmAttributes Attributes (b7 - buspwr, b6 - selfpwr, b5 - rwu)
	db	50					;; Power requirement (div 2 ma)

;; Interface Assocation Descriptor
	db   DSCR_IF_ASSOC_LEN ;; bLength
	db   DSCR_IF_ASSOC     ;; bDescriptorType
	db   0                 ;; bFirstInterface Zero-based index of this interface
	db   2                 ;; bInterfaceCount ( Control, and AudioStreaming)
	db   1                 ;; bFunctionClass AUDIO_FUNCTION
	db   0	             ;; bFunctionSubClass FUNCTION_SUBCLASS_UNDEFINED
	db   020H              ;; bFunctionProtocol AF_VERSION_02_00
	db   0                 ;; iFunction Interface descriptor string index This would be nice to add!
      
;; Alt 0 Interface Descriptor - Control
	db   DSCR_INTRFC_LEN   ;; bLength
	db   DSCR_INTRFC       ;; bDescriptorType
	db   0                 ;; bInterfaceNumber Zero-based index of this interface
	db   0                 ;; bAlternateSetting
	db   0                 ;; bNumEndpoints 	 0 = Control Only; 1 = Control + Interrupt
	db   01H               ;; bInterfaceClass AUDIO
	db   01H               ;; bInterfaceSubClass AUDIOCONTROL
	db   020H              ;; bInterfaceProtocol IP_VERSION_02_00
	db   0                 ;; iInterface descriptor string index This would be nice to add!

;; Class specific Audio Control Descriptor - concat all Clock Descriptor, Ubnit Descriptors, Terminal Desriptors
FullSpeedACDescStrt:	  
;; AC Interface header
	db   09H				 ;; bLength				  9
	db   24H				 ;; bDescriptorType		  CS_INTERFACE
	db   01H				 ;; bDescriptorSubtype	  HEADER
	db   00H				 ;; bcdADC				  VERSION LS
	db   02H				 ;; bcdADC				  VERSION MS
	db   08H				 ;; bCategory			  I/O_BOX
	db   (FullSpeedACDescEnd-FullSpeedACDescStrt) mod 256 ;; wTotalLength	(LSB)
	db   (FullSpeedACDescEnd-FullSpeedACDescStrt)  /  256 ;; wTotalLength (MSB)
	db   00H				 ;; bmControls 00000xx xx indicates Latency Control

;; Clock Source
	db	08H					;;	bLength				8
	db	24H					;;	bDescriptorType		CS_INTERFACE
	db	0AH					;;	bDescriptorSubtype	CLOCK_SOURCE
	db	01H					;;	bClockID			unique
	db	07H					;;	bmAttributes		6 = variable freq synced to SOM 7 = prog but synched to SOF
	db	07H					;;	bmControls			6 = read only control with validity read only; 0 - no controls present
							;;						7 = fully controllable but read only Validity
	db	02H					;;	bAssocTerminal		2 = USB OUT terminal
	db	00H					;;	iClockSource  		descr string

;; Input Terminal
	db	11H					;;	bLength				17
	db	24H					;;	bDescriptorType		CS_INTERFACE
	db	02H					;;	bDescriptorSubtype	INPUT_TERMINAL
	db	02H					;;	bTerminalID			unique
	db	01H					;;	wTerminalType		usb streaming LS
	db	01H					;;	wTerminalType		usb streaming MS
	db	00H					;;	bAssocTerminal
	db	01H					;;	bCSourceID			Clock source ID
	db	02H					;;	bNrChannels			Stereo
	db	03H					;;	bmChannelConfig		Front Left and Front Right	(LS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(most MS)
	db	00H					;;	iChannelNames
	db	00H					;;	bmControls			Not implemented	LS
	db	00H					;;	bmControls			Not implemented MS
	db	00H					;;	iTerminal

;; Output Terminal
	db	0CH					;;	bLength				12
	db	24H					;;	bDescriptorType		CS_INTERFACE
	db	03H					;;	bDescriptorSubtype	OUTPUT_TERMINAL
	db	03H					;;	bTerminalID			unique
	db	01H					;;	wTerminalType		A generic analog connector. LS
	db	06H					;;	wTerminalType		A generic analog connector.	MS
	db	00H					;;	bAssocTerminal		
	db	02H					;;	bCSourceID			Data source ID
	db	01H					;;	bCSourceID			Clock source ID
	db	00H					;;	bmControls			Not implemented	LS
	db	00H					;;	bmControls			Not implemented MS
	db	00H					;;	iTerminal

FullSpeedACDescEnd:
;; Control Endpoint Descriptor NEVER EXPLICITLY DECLARED

;; Interrupt Endpoint Descriptor
;;	db	DSCR_ENDPNT_LEN   ;; Descriptor length
;;	db	DSCR_ENDPNT       ;; Descriptor type
;;	db	81H               ;; Endpoint 1 and direction IN
;;	db	ET_INT            ;; Endpoint type
;;	db	06H               ;; Maximun packet size (LSB)
;;	db	00H               ;; Max packect size (MSB)  6 byte packets/uFrame
;;	db	04H               ;; Polling interval once per 8 uframe ie 1kHz rate

;; Alt 0 Interface Descriptor - AudioStreaming
	db	DSCR_INTRFC_LEN   ;; bLength
	db	DSCR_INTRFC       ;; bDescriptorType
	db	0                 ;; bInterfaceNumber Zero-based index of this interface
	db	0                 ;; bAlternateSetting
	db	0                 ;; bNumEndpoints 0 Default with no bandwidth
	db	01H               ;; bInterfaceClass AUDIO
	db	02H               ;; bInterfaceSubClass AUDIOSTREAMING
	db	020H              ;; bInterfaceProtocol IP_VERSION_02_00
	db	0                 ;; iInterface descriptor string index This would be nice to add!
      
;; Alt 1 Interface Descriptor - AudioStreaming
	db	DSCR_INTRFC_LEN   ;; bLength
	db	DSCR_INTRFC       ;; bDescriptorType
	db	0                 ;; bInterfaceNumber Zero-based index of this interface
	db	1                 ;; bAlternateSetting
	db	1                 ;; bNumEndpoints Main endpoint
	db	01H               ;; bInterfaceClass AUDIO
	db	02H               ;; bInterfaceSubClass AUDIOSTREAMING
	db	020H              ;; bInterfaceProtocol IP_VERSION_02_00
	db	0                 ;; iInterface descriptor string index This would be nice to add!
      
;; Alt 1 Interface Descriptor - Class Specific AudioStreaming
	db	DSCR_AS_INTRFC_LEN	;; bLength
	db	DSCR_AS_INTRFC		;; bDescriptorType	   CS_INTERFACE
	db	01H					;; bDescriptorSubType   AS_GENERAL
	db	2					;; bTerminalLink ID of assoc link (USB streaming)
	db	00H					;; bmControls not implemented
	db	01H					;; bFormatType	FORMAT_TYPE_I
	db	01H					;; bmFormats PCM LS
	db	00H					;; bmFormats PCM
	db	00H					;; bmFormats PCM
	db	00H					;; bmFormats PCM MS
	db	02H					;; bNrChannels			Stereo
	db	03H					;;	bmChannelConfig		Front Left and Front Right	(LS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(next MS)
	db	00H					;;	bmChannelConfig								(most MS)
	db	00H					;; iChannelNames

;; FORMAT_TYPE_I descriptor      
	db	6					;; bLength
	db	DSCR_AS_INTRFC		;; bDescriptorType	   CS_INTERFACE
	db	02H					;; bDescriptorSubType   FORMAT_TYPE
	db	01H					;; bFormatType	FORMAT_TYPE_I
	db	06H					;; bSubslotSize
	db	18H					;; bBitResolution
      
;; Endpoint Descriptor
	db	DSCR_ENDPNT_LEN   ;; Descriptor length
	db	DSCR_ENDPNT       ;; Descriptor type
	db	02H               ;; Endpoint 2 and direction OUT
	db	ET_ISO+0CH        ;; Endpoint type ISO and Synchronous
	db	00H               ;; wMaxPacketSize (LSB)
	db	01H               ;; wMaxPacketSize (MSB)  256 byte packets/uFrame
	db	01H               ;; Polling interval 1 per uFrame

;; AudioStreaming Class Specific Endpoint descriptor
	db	8					;; bLength
	db	0x25				;; bDescriptorType	   CS_ENDPOINT
	db	0x01				;; bDescriptorSubType	   EP_GENERAL
	db	0x00				;; bmAttributes 0x00 = can handle short packets
							;;				0x80 = always needs correct no of packets above
	db	00H					;; bmControls not implemented
	db	01H					;; bLockDelayUnits ms
	db	00H					;; wLockDelay 0.512s LS
	db	02H					;; wLockDelay 0.512s MS

FullSpeedConfigDscrEnd:   

org (($+1)/2)*2	;; align to even address

StringDscr:

StringDscr0:   
      db   StringDscr0End-StringDscr0      ;; String descriptor length
      db   DSCR_STRING
      db   09H,04H
StringDscr0End:

StringDscr1:   
      db   StringDscr1End-StringDscr1      ;; String descriptor length
      db   DSCR_STRING
      db   'C',00
      db   'y',00
      db   'p',00
      db   'r',00
      db   'e',00
      db   's',00
      db   's',00
StringDscr1End:

StringDscr2:   
      db   StringDscr2End-StringDscr2      ;; Descriptor length
      db   DSCR_STRING
      db   'C',00
      db   'Y',00
      db   '-',00
      db   'S',00
      db   't',00
      db   'r',00
      db   'e',00
      db   'a',00
      db   'm',00
StringDscr2End:

StringDscr3:   
      db   StringDscr3End-StringDscr3      ;; Descriptor length
      db   DSCR_STRING
      db   'M',00
      db   'G',00
      db   'N',00
      db   '-',00
      db   'E',00
      db   'l',00
      db   'e',00
      db   'c',00
      db   't',00
StringDscr3End:

StringDscr4:   
      db   StringDscr4End-StringDscr4      ;; Descriptor length
      db   DSCR_STRING
      db   'U',00
      db   'S',00
      db   'B',00
      db   '-',00
      db   'D',00
      db   'A',00
      db   'C',00
StringDscr4End:

StringDscr5:   
      db   StringDscr5End-StringDscr5      ;; Descriptor length
      db   DSCR_STRING
      db   'S',00
      db   'N',00
      db   '.',00
      db   '9',00
      db   '0',00
      db   '0',00
      db   '1',00
StringDscr5End:

org (($+1)/2)*2	;; align to even address

HIDDscr:
      db   09h      ; length
      db   21h      ; type: HID
      db   010h,01h      ; release: HID class rev 1.1
      db   00h      ; country code (none)
      db   01h      ; number of HID class descriptors to follow
      db   22h      ; report descriptor type (HID)
      db   (HIDReportDscrEnd - HIDReportDscr) ; length of HID descriptor
      db   00h
HIDDscrEnd:

HIDReportDscr:
	db 05h, 01h     ; Usage Page (Generic Desktop)
	db 09h, 06h     ; Usage (Keyboard)
	db 0A1h, 01h     ; Collection (Application)
	db 05h, 07h     ;       Usage Page (Key codes)
	db 19h, 0E0h	;	Usage minimum (234)
	db 29h, 0E7h	;	Usage maximum (231)
	db 15h, 00h	;	Logical minimum (0)
	db 25h, 01h	;	Logical maximum (1)
	db 75h, 01h	;	Report size (1)
	db 95h, 08h	;	Report count (8)
	db 81h, 02h	;	Input (data, variable, absolute)
	db 95h, 01h	;	Report count (1)
	db 75h, 08h	;	Report size (8)
	db 81h, 01h	;	Input (constant)
	db 95h, 05h	;	Report count (5)
	db 75h, 01h	;	Report size (1)
	db 05h, 08h	;	Usage Page (LED)
	db 19h, 01h	;	Usage minimum (1)
	db 29h, 05h	;	Usage maximum (5)
	db 91h, 02h	;	Output (data, variable, absolute)
	db 95h, 01h	;	Report count (1)
	db 75h, 03h	;	Report size (3)
	db 91h, 01h	;	Output (constant)
	db 95h, 03h	;	Report count (3)
	db 75h, 08h	;	Report size (8)
	db 15h, 00h	;	Logical minimum (0)
	db 25h, 65h	;	Logical maximum (101)
	db 05h, 07h	;	Usage page (key codes)
	db 19h, 00h	;	Usage minimum (0)
	db 29h, 65h	;	Usage maximum (101)
	db 81h, 00h	;	Input (data, array)
	db 0C0h          ; End Collection
HIDReportDscrEnd:

UserDscr:      
      dw   0000H
      end
      
